import { ReactElement } from 'react';
export declare type typographyTypes = 'heading' | 'body' | 'label';
export declare type typographyVariants = 'h1' | 'h1Light' | 'h2' | 'h3' | 'h4' | 'primary' | 'secondary' | 'tertiary';
export declare type paddingScaleType = 'paddingXXXS' | 'paddingXXS' | 'paddingXS' | 'paddingS' | 'paddingM' | 'paddingL' | 'paddingXL' | 'padding2XL' | 'padding3XL' | 'padding4XL';
export declare type flexboxScaleType = 'spacingXXS' | 'spacingXS' | 'spacingS' | 'spacingM' | 'spacingL' | 'spacingXL' | 'spacing2XL' | 'spacing3XL' | 'spacing4XL' | 'spacing5XL' | 'spacing6XL';
export declare type borderRadiusScaleType = 'borderS' | 'borderM' | 'borderL' | 'borderXL';
export declare type SpacingType = {
    padding: Record<paddingScaleType, string>;
    flexbox: Record<flexboxScaleType, string>;
    borderRadius: Record<borderRadiusScaleType, string>;
};
export declare type TypographyProps = {
    fontSize: string;
    lineHeight: string;
    fontWeight: number;
};
export declare type EffectType = {
    shadow: Record<'20' | '40' | '60' | '80' | '100', string>;
};
export declare type contentType = {
    primary: string;
    secondary: string;
    tertiary: string;
    accent: string;
    danger: string;
    warning: string;
    success: string;
    inverse: {
        primary: string;
        secondary: string;
        tertiary: string;
        accent: string;
    };
};
export declare type backgroundType = {
    primary: string;
    secondary: string;
    brand: string;
    brandDark: string;
    danger: {
        base: string;
        subtle: string;
    };
    warning: {
        base: string;
        subtle: string;
    };
    success: {
        base: string;
        subtle: string;
    };
};
export declare type textIconPropsType = {
    default: string;
    hover: string;
    disabled: string;
};
export declare type actionPropsType = textIconPropsType & {
    active: string;
};
export declare type actionType = {
    background: {
        primary: {
            base: actionPropsType;
            subtle: actionPropsType;
        };
        secondary: {
            base: actionPropsType;
            subtle: actionPropsType;
        };
        tertiary: {
            base: actionPropsType;
            subtle: actionPropsType;
        };
        danger: actionPropsType;
        success: actionPropsType;
        warning: actionPropsType;
    };
    textIcon: {
        primary: textIconPropsType & {
            inverse: textIconPropsType;
        };
        secondary: textIconPropsType;
        tertiary: textIconPropsType;
        danger: textIconPropsType;
        success: textIconPropsType;
        warning: textIconPropsType;
        input: textIconPropsType;
    };
};
export declare type borderType = {
    primary: string;
    secondary: string;
    tertiary: string;
    focus: string;
    danger: string;
    warning: string;
    success: string;
    dark: string;
};
export declare type ColorsType = {
    content: contentType;
    background: backgroundType;
    action: actionType;
    border: borderType;
};
export declare type TypographyType = {
    desktop: typographyPropsType;
    mobile: typographyPropsType;
};
export declare type typographyPropsType = {
    heading: headingsType;
    body: bodyType;
    label: bodyType;
    input: inputType;
};
export declare type fontPropsType = {
    fontFamily: string;
    fontWeight: string;
    lineHeight: string;
    fontSize: string;
    letterSpacing: string;
    textDecoration?: string;
    textCase?: string;
};
export declare type headingsType = {
    h1: fontPropsType;
    h1Light: fontPropsType;
    h2: fontPropsType;
    h3: fontPropsType;
    h4: fontPropsType;
};
export declare type inputType = {
    primary: fontPropsType;
    secondary: fontPropsType;
};
export declare type bodyType = inputType & {
    tertiary: fontPropsType;
};
export declare type ThemeType = {
    colors: ColorsType;
    spacing: SpacingType;
    typography: TypographyType;
    effects: EffectType;
    tokens?: Record<string, unknown>;
};
export declare type BolttechThemeProviderPropsType = {
    children?: ReactElement | ReactElement[];
    theme: ThemeType;
};
