"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createColorClasses = void 0;

var _Color = require("./Color.js");
/**
 * This function is responsible to create class auxiliary for text colors and backgrounds
 * it uses a recursion to get to all possible properties of the theme and extract
 * all the colors used there and generate classes based on the properties names.
 * @param {object | string} currentObject
 * @param {string} property
 */


const getColorProperties = (currentObject, property = '') => {
  if (typeof currentObject === 'string') {
    return `
    .text${property} {
      color: ${currentObject};
    }
    .bg${property} {
      background-color: ${currentObject};
    }
    .fill${property} {
      ${(0, _Color.getFilteredColor)(currentObject)}
    }
  `;
  } else {
    return Object.keys(currentObject).map(currentObjectKey => {
      return getColorProperties(currentObject[currentObjectKey], `${property}-${currentObjectKey}`);
    }).join('');
  }
};
/**
 * This function is responsible to create class auxiliary for text colours and backgrounds
 * and backgrounds using the theme itself.
 * @param {ThemeType} theme
 */


const createColorClasses = theme => {
  return getColorProperties(theme.colors);
};

exports.createColorClasses = createColorClasses;